@@ -37,6 +37,7 @@ class Azure(OpenaiTemplate):
         }
     }
     api_keys: dict[str, str] = {}
+    failed: dict[str, int] = {}
 
     @classmethod
     def get_models(cls, api_key: str = None, **kwargs) -> list[str]:
@@ -54,6 +55,8 @@ class Azure(OpenaiTemplate):
                 raise ValueError(f"Invalid AZURE_ROUTES environment variable format: {routes}")
             cls.routes = routes
         if cls.routes:
+            if cls.live == 0 and cls.api_keys:
+                cls.live += 1
             return list(cls.routes.keys())
         return super().get_models(api_key=api_key, **kwargs)
 
@@ -87,7 +90,7 @@ class Azure(OpenaiTemplate):
         if api_endpoint and "/images/" in api_endpoint:
             prompt = format_media_prompt(messages, kwargs.get("prompt"))
             width, height = get_width_height(kwargs.get("aspect_ratio", "1:1"), kwargs.get("width"), kwargs.get("height"))
-            output_format = kwargs.get("output_format", "webp")
+            output_format = kwargs.get("output_format", "png")
             form = None
             data = None
             if media:
@@ -131,6 +134,8 @@ class Azure(OpenaiTemplate):
             stream = False
         if stream:
             kwargs.setdefault("stream_options", {"include_usage": True})
+        if cls.failed.get(api_key, 0) >= 3:
+            raise MissingAuthError(f"API key has failed too many times.")
         try:
             async for chunk in super().create_async_generator(
                 model=model,
@@ -143,4 +148,5 @@ class Azure(OpenaiTemplate):
             ):
                 yield chunk
         except MissingAuthError as e:
+            cls.failed[api_key] = cls.failed.get(api_key, 0) + 1
             raise MissingAuthError(f"{e}. Ask for help in the {cls.login_url} Discord server.") from e
\ No newline at end of file
