@@ -20,8 +20,8 @@ except ImportError:
 class DeepSeekAPI(AsyncAuthedProvider, ProviderModelMixin):
     label = "DeepSeek"
     url = "https://chat.deepseek.com"
-    working = has_dsk
-    active_by_default = has_dsk
+    working = False
+    active_by_default = False
     needs_auth = True
     use_nodriver = True
     _access_token = None
