@@ -24,5 +24,7 @@ GITHUB_REPOSITORY = f"xtekky/{ORGANIZATION}"
 STATIC_DOMAIN = f"{PACKAGE_NAME}.dev"
 STATIC_URL = f"https://{STATIC_DOMAIN}/"
 DIST_DIR = f"./{STATIC_DOMAIN}/dist"
-DOWNLOAD_URL = f"https://raw.githubusercontent.com/{ORGANIZATION}/{STATIC_DOMAIN}/refs/heads/main/"
-DEFAULT_MODEL = "openai/gpt-oss-120b"
\ No newline at end of file
+DEFAULT_MODEL = "openai/gpt-oss-120b"
+JSDELIVR_URL = "https://cdn.jsdelivr.net/"
+DOWNLOAD_URL = f"{JSDELIVR_URL}gh/{ORGANIZATION}/{STATIC_DOMAIN}/"
+GITHUB_URL = f"https://raw.githubusercontent.com/{ORGANIZATION}/{STATIC_DOMAIN}/refs/heads/main/"
\ No newline at end of file
