@@ -10,7 +10,7 @@ from ..providers.retry_provider import RotatedProvider
 from ..Provider.needs_auth import OpenaiChat, CopilotAccount
 from ..Provider.hf_space import HuggingSpace
 from ..Provider import Custom, PollinationsImage, OpenaiAccount, Copilot, Cloudflare, Gemini, Grok, PerplexityLabs, LambdaChat, PollinationsAI, PuterJS
-from ..Provider import Microsoft_Phi_4_Multimodal, DeepInfraChat, LMArenaBeta, EdgeTTS, gTTS, MarkItDown, OpenAIFM
+from ..Provider import Microsoft_Phi_4_Multimodal, DeepInfra, LMArena, EdgeTTS, gTTS, MarkItDown, OpenAIFM
 from ..Provider import HuggingFace, HuggingFaceMedia, Azure, Qwen, EasyChat, GLM, OpenRouterFree, GeminiPro
 from .base_provider import AsyncGeneratorProvider, ProviderModelMixin
 from .. import Provider
@@ -25,7 +25,7 @@ PROVIDERS_LIST_2 = [
 
 # Add all models to the model map
 PROVIDERS_LIST_3 = [
-    LambdaChat, DeepInfraChat, HuggingFace, HuggingFaceMedia, LMArenaBeta,
+    LambdaChat, DeepInfra, HuggingFace, HuggingFaceMedia, LMArena,
     PuterJS, Cloudflare, HuggingSpace
 ]
 
@@ -220,6 +220,7 @@ class AnyModelProviderMixin(ProviderModelMixin):
 
         cls.video_models.append("video")
         cls.model_map["video"] = {"Video": "video"}
+        del cls.model_map[""]
         cls.audio_models = [*cls.audio_models]
 
         # Create a mapping of parent providers to their children
@@ -415,7 +416,7 @@ def clean_name(name: str) -> str:
     name = re.sub(r'-\d{2}-\d{2}', '', name)
     name = re.sub(r'-[0-9a-f]{8}$', '', name)
     # Version patterns
-    name = re.sub(r'-(instruct|chat|preview|experimental|v\d+|fp8|bf16|hf|free|tput)$', '', name)
+    name = re.sub(r'-(instruct|preview|experimental|v\d+|fp8|bf16|hf|free|tput)$', '', name)
     # Other replacements
     name = name.replace("_", ".")
     name = name.replace("c4ai-", "")
