@@ -21,6 +21,7 @@ from .response import BaseConversation, AuthResult
 from .helper import concat_chunks
 from ..cookies import get_cookies_dir
 from ..errors import ModelNotFoundError, ResponseError, MissingAuthError, NoValidHarFileError, PaymentRequiredError, CloudflareError
+from ..tools.run_tools import AuthManager
 from .. import debug
 
 SAFE_PARAMETERS = [
@@ -284,6 +285,7 @@ class AsyncGeneratorProvider(AbstractProvider):
     Provides asynchronous generator functionality for streaming results.
     """
     supports_stream = True
+    use_stream_timeout = True
 
     @classmethod
     def create_completion(
@@ -291,6 +293,7 @@ class AsyncGeneratorProvider(AbstractProvider):
         model: str,
         messages: Messages,
         timeout: int = None,
+        stream_timeout: int = None,
         **kwargs
     ) -> CreateResult:
         """
@@ -308,7 +311,7 @@ class AsyncGeneratorProvider(AbstractProvider):
         """
         return to_sync_generator(
             cls.create_async_generator(model, messages, **kwargs),
-            timeout=timeout
+            timeout=stream_timeout if cls.use_stream_timeout is None else timeout,
         )
 
     @staticmethod
@@ -335,7 +338,7 @@ class AsyncGeneratorProvider(AbstractProvider):
         raise NotImplementedError()
 
     @classmethod
-    def async_create_function(cls, *args, **kwargs) -> AsyncResult:
+    async def async_create_function(cls, *args, **kwargs) -> AsyncResult:
         """
         Creates a completion using the synchronous method.
 
@@ -345,7 +348,19 @@ class AsyncGeneratorProvider(AbstractProvider):
         Returns:
             CreateResult: The result of the completion creation.
         """
-        return cls.create_async_generator(*args, **kwargs)
+        response = cls.create_async_generator(*args, **kwargs)
+        if "stream_timeout" in kwargs or "timeout" in kwargs:
+            while True:
+                try:
+                    yield await asyncio.wait_for(
+                        response.__anext__(),
+                        timeout=kwargs.get("stream_timeout") if cls.use_stream_timeout else kwargs.get("timeout")
+                    )
+                except StopAsyncIteration:
+                    break
+        else:
+            async for chunk in response:
+                yield chunk
 
 class ProviderModelMixin:
     default_model: str = None
@@ -357,11 +372,20 @@ class ProviderModelMixin:
     video_models: list = []
     audio_models: dict = {}
     last_model: str = None
+    models_loaded: bool = False
 
     @classmethod
-    def get_models(cls, **kwargs) -> list[str]:
+    def get_models(cls, api_key: str = None, **kwargs) -> list[str]:
         if not cls.models and cls.default_model is not None:
             cls.models = [cls.default_model]
+        if not cls.models_loaded and hasattr(cls, "get_cache_file"):
+            if cls.get_cache_file().exists():
+                cls.live += 1
+            elif not api_key:
+                api_key = AuthManager.load_api_key(cls)
+                if api_key:
+                    cls.live += 1
+        cls.models_loaded = True
         return cls.models
 
     @classmethod
@@ -444,8 +468,8 @@ class AsyncAuthedProvider(AsyncGeneratorProvider, AuthFileMixin):
                     json.dump(auth_result, cache_file, default=toJSON)
             except TypeError as e:
                 raise RuntimeError(f"Failed to save: {auth_result.get_dict()}\n{type(e).__name__}: {e}")
-         elif cache_file.exists():
-            cache_file.unlink()
+         # elif cache_file.exists():
+         #    cache_file.unlink()
 
     @classmethod
     def get_auth_result(cls) -> AuthResult:
@@ -482,7 +506,7 @@ class AsyncAuthedProvider(AsyncGeneratorProvider, AuthFileMixin):
                     auth_result = chunk
                 else:
                     yield chunk
-            for chunk in to_sync_generator(cls.create_authed(model, messages, auth_result, **kwargs)):
+            for chunk in to_sync_generator(cls.create_authed(model, messages, auth_result, **kwargs), kwargs.get("stream_timeout", kwargs.get("timeout"))):
                 if cache_file is not None:
                     cls.write_cache_file(cache_file, auth_result)
                     cache_file = None
@@ -500,11 +524,21 @@ class AsyncAuthedProvider(AsyncGeneratorProvider, AuthFileMixin):
         try:
             auth_result = cls.get_auth_result()
             response = to_async_iterator(cls.create_authed(model, messages, **kwargs, auth_result=auth_result))
-            async for chunk in response:
-                yield chunk
+            if "stream_timeout" in kwargs or "timeout" in kwargs:
+                while True:
+                    try:
+                        yield await asyncio.wait_for(
+                            response.__anext__(),
+                            timeout=kwargs.get("stream_timeout") if cls.use_stream_timeout else kwargs.get("timeout")
+                        )
+                    except StopAsyncIteration:
+                        break
+            else:
+                async for chunk in response:
+                    yield chunk
         except (MissingAuthError, NoValidHarFileError, CloudflareError):
-            if cache_file.exists():
-                cache_file.unlink()
+            # if cache_file.exists():
+            #     cache_file.unlink()
             response = cls.on_auth_async(**kwargs)
             async for chunk in response:
                 if isinstance(chunk, AuthResult):
